OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Import contacts",
    "Details" : "Details",
    "All contacts" : "All contacts",
    "Contacts" : "Contacts",
    "A contacts app for Nextcloud" : "A contacts app for Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library.",
    "Copy to full name" : "Copy to full name",
    "Omit year" : "Omit year",
    "Allow updating avatars from social media" : "Allow updating avatars from social media",
    "There was an error fetching the member list" : "There was an error fetching the member list",
    "There are no contacts yet" : "There are no contacts yet",
    "Create contact" : "Create contact",
    "There are no contacts in this group" : "There are no contacts in this group",
    "Create contacts" : "Create contacts",
    "Add contacts" : "Add contacts",
    "Contacts settings" : "Contacts settings",
    "General" : "General",
    "Update avatars from social media" : "Update avatars from social media",
    "Address books" : "Address books",
    "Rename" : "Rename",
    "Export" : "Export",
    "Send email" : "Send email",
    "Send email as BCC" : "Send email as BCC",
    "Delete" : "Delete",
    "Show all groups" : "Show all groups",
    "Collapse groups" : "Collapse groups",
    "This group already exists" : "This group already exists",
    "Recently contacted" : "Recently contacted",
    "Contact groups" : "Contact groups",
    "Create a new contact group" : "Create a new contact group",
    "Contact group name" : "Contact group name",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Shared with {num} entity","Shared with {num} entities"],
    "Copied" : "Copied",
    "Cannot copy" : "Cannot copy",
    "Copy link" : "Copy link",
    "Toggling of address book was not successful" : "Toggling of address book was not successful",
    "This will delete the address book and every contacts within it" : "This will delete the address book and every contacts within it",
    "Delete {addressbook}?" : "Delete {addressbook}?",
    "Deletion of address book was not successful." : "Deletion of address book was not successful.",
    "Renaming of address book was not successful." : "Renaming of address book was not successful.",
    "Download" : "Download",
    "Show" : "Show",
    "_%n contact_::_%n contacts_" : ["%n contact","%n contacts"],
    "_%n group_::_%n groups_" : ["%n group","%n groups"],
    "Share with users or groups" : "Share with users or groups",
    "Share with users" : "Share with users",
    "No users or groups" : "No users or groups",
    "Unable to delete the share" : "Unable to delete the share",
    "Unable to change permissions" : "Unable to change permissions",
    "Choose a vCard file to import" : "Choose a vCard file to import",
    "Import into the {addressbookName} address book" : "Import into the {addressbookName} address book",
    "Select local file" : "Select local file",
    "Import from files" : "Import from files",
    "Importing is disabled because there are no address books available" : "Importing is disabled because there are no address books available",
    "An error occurred, unable to create the address book" : "An error occurred, unable to create the address book",
    "Add new address book" : "Add new address book",
    "Cancel" : "Cancel",
    "Add" : "Add",
    "First name" : "First name",
    "Last name" : "Last name",
    "Phonetic first name" : "Phonetic first name",
    "Phonetic last name" : "Phonetic last name",
    "Display name" : "Display name",
    "Last modified" : "Last modified",
    "Manages" : "Manages",
    "Oversees" : "Oversees",
    "An error happened during the config change" : "An error happened during the config change",
    "Save" : "Save",
    "Change unique password" : "Change unique password",
    "Failed to save password. Please try again later." : "Failed to save password. Please try again later.",
    "Close" : "Close",
    "Delete picture" : "Delete picture",
    "Edit" : "Edit",
    "Request to join" : "Request to join",
    "You are not a member of {circle}" : "You are not a member of {circle}",
    "Add more info" : "Add more info",
    "More fields" : "More fields",
    "Please select a valid format" : "Please select a valid format",
    "Invalid image" : "Invalid image",
    "Error cropping picture" : "Error cropping picture",
    "Pick an avatar" : "Pick an avatar",
    "Error while processing the picture." : "Error while processing the picture.",
    "Avatar downloaded from social network" : "Avatar downloaded from social network",
    "Avatar already up to date" : "Avatar already up to date",
    "Avatar download failed" : "Avatar download failed",
    "Crop contact photo" : "Crop contact photo",
    "Upload a new picture" : "Upload a new picture",
    "Choose from Files" : "Choose from Files",
    "Download picture" : "Download picture",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "This contact is in read-only mode. You do not have permission to edit this contact.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded.",
    "Address book" : "Address book",
    "Add contact to Birthday Calendar" : "Add contact to Birthday Calendar",
    "Exclude contact from Birthday Calendar" : "Exclude contact from Birthday Calendar",
    "{title} at {organization}" : "{title} at {organization}",
    "Name" : "Name",
    "Syntax error. Cannot open the contact." : "Syntax error. Cannot open the contact.",
    "The contact does not exist on the server anymore." : "The contact does not exist on the server anymore.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Unable to retrieve the contact from the server, please check your network connection.",
    "An error occurred while trying to move the contact" : "An error occurred while trying to move the contact",
    "An error occurred while trying to copy the contact" : "An error occurred while trying to copy the contact",
    "Unable to update contact" : "Unable to update contact",
    "No contact selected" : "No contact selected",
    "Select a contact on the list to begin" : "Select a contact on the list to begin",
    "Title" : "Title",
    "Company" : "Company",
    "Go to talk conversation" : "Go to talk conversation",
    "View profile" : "View profile",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "This contact was broken and received a fix. Please review the content and click here to save it.",
    "Clone contact" : "Clone contact",
    "Generate QR Code" : "Generate QR Code",
    "Contact vCard as QR code" : "Contact vCard as QR code",
    "Pick an address book" : "Pick an address book",
    "Select address book" : "Select address book",
    "Media shares with you" : "Media shares with you",
    "Talk conversations with you" : "Talk conversations with you",
    "Calendar events with you" : "Calendar events with you",
    "Deck cards with you" : "Deck cards with you",
    "No shared items with this contact" : "No shared items with this contact",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Add to {group}" : "Add to {group}",
    "Remove {type}" : "Remove {type}",
    "Add to group" : "Add to group",
    "Search {types}" : "Search {types}",
    "Search for people to add" : "Search for people to add",
    "No results" : "No results",
    "Add {type}" : "Add {type}",
    "Promote as sole owner" : "Promote as sole owner",
    "Promote to {level}" : "Promote to {level}",
    "Demote to {level}" : "Demote to {level}",
    "Could not delete the member {displayName}" : "Could not delete the member {displayName}",
    "Could not change the member level to {level}" : "Could not change the member level to {level}",
    "Could not accept membership request" : "Could not accept membership request",
    "Accept membership request" : "Accept membership request",
    "Reject membership request" : "Reject membership request",
    "Manage level" : "Manage level",
    "Remove member" : "Remove member",
    "Unable to get the results" : "Unable to get the results",
    "Some members could not be added" : "Some members could not be added",
    "You currently have no access to the member list" : "You currently have no access to the member list",
    "Pending" : "Pending",
    "Chart" : "Chart",
    "Select Date" : "Select Date",
    "Select type" : "Select type",
    "Add contact in group" : "Add contact in group",
    "None" : "None",
    "Select option" : "Select option",
    "Notes" : "Notes",
    "Add property of this type" : "Add property of this type",
    "Member" : "Member",
    "Unable to create the contact." : "Unable to create the contact.",
    "Contact not found" : "Contact not found",
    "Group {group} not found" : "Group {group} not found",
    "Add member" : "Add member",
    "New contact" : "New contact",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contact added to {name}","{success} contacts added to {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Adding {success} contact to {name}","Adding {success} contacts to {name}"],
    "_{count} error_::_{count} errors_" : ["{count} error","{count} errors"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importing %n contact into {addressbook}","Importing %n contacts into {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Done importing %n contact into {addressbook}","Done importing %n contacts into {addressbook}"],
    "Import" : "Import",
    "Could not copy" : "Could not copy",
    "You are about to leave {circle}.\nAre you sure?" : "You are about to leave {circle}.\nAre you sure?",
    "You are about to delete {circle}.\nAre you sure?" : "You are about to delete {circle}.\nAre you sure?",
    "Link copied to the clipboard" : "Link copied to the clipboard",
    "Could not copy link to the clipboard." : "Could not copy link to the clipboard.",
    "Not grouped" : "Not grouped",
    "Organization chart" : "Organization chart",
    "User" : "User",
    "Group" : "Group",
    "Email" : "Email",
    "Contact" : "Contact",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Invites" : "Invites",
    "Anyone can request membership" : "Anyone can request membership",
    "Members need to accept invitation" : "Members need to accept invitation",
    "Members can also invite" : "Members can also invite",
    "Visible to everyone" : "Visible to everyone",
    "Users" : "Users",
    "Email addresses" : "Email addresses",
    "Detailed name" : "Detailed name",
    "Additional names" : "Additional names",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Nickname" : "Nickname",
    "Website" : "Website",
    "Location" : "Location",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Home",
    "Work" : "Work",
    "Other" : "Other",
    "Address" : "Address",
    "Post office box" : "Post office box",
    "Extended address" : "Extended address",
    "City" : "City",
    "State or province" : "State or province",
    "Postal code" : "Postal code",
    "Country" : "Country",
    "Birthday" : "Birthday",
    "Anniversary" : "Anniversary",
    "Date of death" : "Date of death",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Phone",
    "Mobile" : "Mobile",
    "Work mobile" : "Work mobile",
    "Home mobile" : "Home mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax home",
    "Fax work" : "Fax work",
    "Pager" : "Pager",
    "Voice" : "Voice",
    "Car" : "Car",
    "Work pager" : "Work pager",
    "Social network" : "Social network",
    "Relationship to you" : "Relationship to you",
    "Spouse" : "Spouse",
    "Child" : "Child",
    "Mother" : "Mother",
    "Father" : "Father",
    "Parent" : "Parent",
    "Brother" : "Brother",
    "Sister" : "Sister",
    "Relative" : "Relative",
    "Friend" : "Friend",
    "Colleague" : "Colleague",
    "Assistant" : "Assistant",
    "Related contacts" : "Related contacts",
    "Agent" : "Agent",
    "Emergency" : "Emergency",
    "Co-worker" : "Co-worker",
    "Gender" : "Gender",
    "Female" : "Female",
    "Male" : "Male",
    "Unknown" : "Unknown",
    "Time zone" : "Time zone",
    "Spoken languages" : "Spoken languages",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contact failed to be read","{failed} contacts failed to be read"],
    "Unable to delete contact" : "Unable to delete contact"
},
"nplurals=2; plural=(n!=1);");
